=== modified file 'bzrlib/tests/test_init.py'
--- bzrlib/tests/test_init.py	2007-05-15 17:40:32 +0000
+++ bzrlib/tests/test_init.py	2007-05-18 18:20:31 +0000
@@ -27,9 +27,21 @@
 from bzrlib.transport.ftp import FtpTransport
 
 
+class TransportHooks(Hooks):
+    """Dict-mapping hook name to a list of callables for transport hooks"""
+
+    def __init__(self):
+        Hooks.__init__(self)
+        # invoked when the transport is about to create or reuse
+        # an ftp connection. The api signature is (transport, ftp_instance)
+        self['get_FTP'] = []
+
+
 class InstrumentedTransport(FtpTransport):
     """Instrumented transport class to test use by init command"""
 
+    hooks = TransportHooks()
+
     def _get_FTP(self):
         """See FtpTransport._get_FTP.
 
@@ -38,41 +50,11 @@
         easiest until transport classes are refactored.
         """
         instance = super(InstrumentedTransport, self)._get_FTP()
-        self.hooks.run_hook('get_FTP', self, instance)
+        for hook in self.hooks['get_FTP']:
+            hook(self, instance)
         return instance
 
 
-class TransportHooks(Hooks):
-    """Dict-mapping hook name to a list of callables for transport hooks"""
-
-    def __init__(self):
-        Hooks.__init__(self)
-        # invoked when the transport is about to create or reuse
-        # an ftp connection. The api signature is (transport, ftp_instance)
-        self['get_FTP'] = []
-
-    # FIXME: Why don't we have Hooks.run_hooks ?
-    def run_hook(self, hook_name, *args, **kwargs):
-        try:
-            hooks = self[hook_name]
-        except KeyError:
-            raise errors.UnknownHook(self.__class__.__name__, hook_name)
-        for hook in hooks:
-            hook(*args, **kwargs)
-
-    # FIXME: Why don't we have Hooks.uninstall_hook ?
-    def uninstall_hook(self, hook_name, a_callable):
-        try:
-            self[hook_name].remove(a_callable)
-        except KeyError:
-            raise errors.UnknownHook(self.__class__.__name__, hook_name)
-        # FIXME: catch ValueError and raise errors.UnknownHookValue ?
-
-
-# install the default hooks into the Branch class.
-InstrumentedTransport.hooks = TransportHooks()
-
-
 class TestInit(TestCaseWithFTPServer):
 
     def setUp(self):
@@ -83,8 +65,7 @@
         register_transport('ftp://', InstrumentedTransport)
 
         def cleanup():
-            InstrumentedTransport.hooks.uninstall_hook('get_FTP',
-                                                       self.get_connection_hook)
+            InstrumentedTransport.hooks = TransportHooks()
             unregister_transport('ftp://', InstrumentedTransport)
 
         self.addCleanup(cleanup)
@@ -100,5 +81,3 @@
         cmd.run(self.get_url())
         self.assertEquals(1, len(self.connections))
 
-    def test_branch(self):
-        

=== modified file 'bzrlib/transport/ftp.py'
--- bzrlib/transport/ftp.py	2007-05-15 17:40:32 +0000
+++ bzrlib/transport/ftp.py	2007-05-18 18:20:31 +0000
@@ -111,7 +111,8 @@
             # urlparse won't handle aftp://, delete the leading 'a'
 
             # FIXME: This breaks even hopes of connection sharing
-            # by modifying the the url coming from the user.
+            # (by reusing the url instead of true cloning) by
+            # modifying the the url coming from the user.
             base = base[1:]
         if not base.endswith('/'):
             base += '/'

